Crate fenris_quadrature

Crate fenris_quadrature 

Quadrature rules for finite element reference domains.

The main purpose of this crate is to support the fenris FEM library. However, it has been designed so that the quadrature rules available here may be used completely independently of fenris.

Reference domains

Segment (1D)

The reference domain in 1D is the interval [-1, 1].

Triangle (2D)

The reference triangle is comprised of the vertices (-1, -1), (1, -1) and (-1, 1).

Reference triangle

Quadrilateral (2D)

The reference quadrilateral is the square [-1, 1]^2, comprised of the vertices (-1, -1), (1, -1), (1, 1) and (-1, 1).

Reference quadrilateral

Hexahedron (3D)

The reference hexahedron is the box [-1, 1]^3.

Reference hexahedron

Tetrahedron (3D)

The reference tetrahedron is comprised of the vertices (-1, -1, -1), (1, -1, -1), (-1, 1, -1) and (-1, -1, 1).

Reference tetrahedron

Pyramid (3D)

The reference pyramid is comprised of the vertices (-1, -1, -1), (1, -1, -1), (1, 1, -1), (-1, 1, -1) and (0, 0, 1).

Reference pyramid

Prism (3D)

The reference prism is comprised of the vertices (-1, -1, -1), (1, -1, -1), (-1, 1, -1), (-1, -1, 1), (1, -1, 1) and (-1, 1, 1).

Reference prism

TODO: Document how quadratures work, e.g. the concept of a reference domain and that quadrature rules are specific to a reference domain

Modules

polyquad
Quadrature rules for various 2D and 3D domains generated by polyquad.
tensor
2D and 3D quadrature rules formed by tensor product formulations.
univariate
Quadrature rules for the one-dimensional domain [-1, 1].

Enums

Error
Library-wide error type.

Functions

integrate
Integrates the given function with the given quadrature rule.

Type Aliases

Point
A D-dimensional point.
Rule
A D-dimensional quadrature rule.